def total_sum (*args: float)-> float:
    """Retorna a soma total dos argumentos."""
    total=0
    for n in args:
        total+=n
    return total

def total_product (*args:float)-> float:
    """Retorna o produto total dos argumentos."""
    total=1
    for n in args:
        total*=n
    return total



def fibonacci(n_termo: int)->int:
    """
    Recebe: quantidade de termos requeridos.
    Retorna: a lista os termos da sequência de fibonacci.
    """
    termo= 1
    termo2=1
    lista_termos=[]
    for i in range(1, n_termo+1):
        if i==1:
            lista_termos.append(termo)
        elif i==2:
            lista_termos.append(termo2)
        else:
            termo_n=termo+termo2
            lista_termos.append(termo_n)
            termo = termo2
            termo2 = termo_n

    return (lista_termos)
        
def fatorial (num: int)->int:
    """
    Recebe: Um número natural.
    Retorna: O fatorial do número.
    """
    fat=1
    if num<0:
        print('Valor inválido. O fatorial só é válido para números naturais')
    elif num==0 or num==1:
        return fat
    else:
        for i in range(1,num+1):
            fat*=i
        return fat


def delta (a:(int, float), b:(int, float), c:(int, float)) -> int,float:
    """
    Recebe: coeficientes a, b e c de uma equação de segundo grau
    Retorna: valor de delta.
    """
    return ((b**2) -4*a*c)


def bhaskara (a:(int, float), b:(int, float), c:(int, float)) -> int,float:
    """
    Recebe: coeficientes a, b e c de uma equação de segundo grau
    Retorna: os valores de x, ou None, se não houver raízes reais.
    """
    if delta(a,b,c) > 0:
        x1 = (-b + delta**(1/2))/(2*a)
        x2 = (-b - delta**(1/2))/(2*a)
        return([x1, x2])
    elif delta == 0: 
        return ((-b + delta**(1/2))/(2*a))
    else: 
        print('Não possui raízes reais')
        return (None)